Package: marray
Version: 1.90.0
Date: 2009-08-15
Title: Exploratory analysis for two-color spotted microarray data
Author: Yee Hwa (Jean) Yang <jeany@maths.usyd.edu.au> with contributions
        from Agnes Paquet and Sandrine Dudoit.
Depends: R (>= 2.10.0), limma, methods
Suggests: tkWidgets
Maintainer: Yee Hwa (Jean) Yang <jean@biostat.ucsf.edu>
Description: Class definitions for two-color spotted microarray data.
        Fuctions for data input, diagnostic plots, normalization and
        quality checking.
License: LGPL
URL: http://www.maths.usyd.edu.au/u/jeany/
biocViews: Microarray, TwoChannel, Preprocessing
Collate: maClasses.R maGet.R maSet.R maPrint.R maSubset.R maBind.R
        maComp.R maDots.R maInput.R maNorm.R maOutput.R maWidget.R
        maPlots.R maAnnotate.R maRankGenes.R maSMA.R maSearch.R
        maWrap.R
LazyLoad: yes
git_url: https://git.bioconductor.org/packages/marray
git_branch: RELEASE_3_23
git_last_commit: 5983b33
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:40:37 UTC; biocbuild
Built: R 4.6.0; ; 2026-04-29 04:48:51 UTC; unix
