Interested in contributing?

If you're knew to contributing on GitHub, learn the nuts and bolts of the process
at [Contributing to a project](https://docs.github.com/en/get-started/exploring-projects-on-github/contributing-to-a-project).

Typical contributions include:

- Filing [issues](https://github.com/mdhaber/marray/issues)
  (e.g. bug reports and feature requests)
- Triaging (adding new information to facilitate resolution of an issue)
- Code (submitting [pull requests](https://github.com/mdhaber/marray/pulls),
  especially to resolve open issues)
- Improving documentation

Interest in contributing is always appreciated! Note that some potential
contributions are more aligned with project goals than others. Please seek
feedback about your idea in an issue before starting significant work on a
pull request.
