# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 1.0     | :white_check_mark: |
| < 1.0   | :x:                |

## Reporting a Vulnerability

Please report potential security vulnerabilities by email to `matt.haberland@gmail.com`.
If the security vulnerability is recognized as a threat, a patch will be crafted
privately to prepare a dedicated bugfix release.
