\name{Internal functions}
\alias{read.fname}
\alias{stat.gene.cluster}
\alias{plot.gene.cluster}
\alias{tablegen}
\alias{gsubAnchor}

\title{Internal marray functions}
 
\description{Internal marray functions}
 
\details{These are not to be called by the user.}

\keyword{methods}
